import {Component, OnInit} from '@angular/core';
import {ActivatedRoute, Router} from '@angular/router';
import {SpeciesAnalysis} from 'src/app/models/SpeciesAnalysis';
import {DataService} from 'src/app/services/data.service';

import {MultipleFamilyAnalysis} from "../../models/MultipleFamilyAnalysis";

@Component({
  selector: 'slf-family',
  templateUrl: './family.component.html',
  styleUrls: ['./family.component.scss']
})
export class FamilyComponent implements OnInit {
  public readonly id: string;
  private multipleFamilyAnalysis?: MultipleFamilyAnalysis;
  public speciesNames?: string[];
  public currentSpeciesName: string = '';
  public currentSpeciesResults: SpeciesAnalysis[] = [];
  public readonly displayedColumns = ['species', 'result', 'actions'];

  constructor(
    private route: ActivatedRoute,
    private readonly router: Router,
    private dataService: DataService
  ) {
    const paramMap = this.route.snapshot.paramMap;
    if (!paramMap.has('id')) {
      this.router.navigate(['/']);
      throw new Error('Missing id');
    }
    this.id = <string>paramMap.get('id');
  }

  public ngOnInit(): void {
    this.dataService.getMultipleFamilyAnalysis()
      .subscribe(mfa => {
        this.multipleFamilyAnalysis = mfa;
        this.speciesNames = Object.keys(mfa.all_results[this.id].results);
        this.changeCurrentSpecies(this.speciesNames[0]);
      });
  }

  public extractResultId(speciesAnalysis: SpeciesAnalysis): string {
    const name = speciesAnalysis.directory;
    return name.substring(name.lastIndexOf('/') + 1);
  }

  private changeCurrentSpecies(speciesName: string): void {
    if (this.multipleFamilyAnalysis !== undefined) {
      this.currentSpeciesName = speciesName;
      this.currentSpeciesResults =
        this.currentSpeciesResults = [this.multipleFamilyAnalysis.all_results[this.id].results[this.currentSpeciesName]];
    } else {
      console.error('this.multipleFamilyAnalysis is undefined');
    }
  }

  public onChangeSpecies(speciesName: string): void {
    this.changeCurrentSpecies(speciesName);
  }
}
