import {AfterViewInit, Component, ElementRef, OnInit, ViewChild} from '@angular/core';
import PhylocanvasGL, {TreeTypes} from "@phylocanvas/phylocanvas.gl";
import {Router} from '@angular/router';
import {DataService} from 'src/app/services/data.service';
import {MatDialog} from '@angular/material/dialog';

@Component({
  selector: 'slf-home',
  templateUrl: './home.component.html',
  styleUrls: ['./home.component.scss']
})
export class HomeComponent implements OnInit, AfterViewInit {
  @ViewChild("demo") demoDiv!: ElementRef<HTMLDivElement>;
  private tree: PhylocanvasGL;

  constructor(private dataService: DataService,
              private router: Router,
              public dialog: MatDialog) {
  }

  ngOnInit(): void {
  }

  ngAfterViewInit() {
    this.renderizeFilogeneticTree();
  }

  private renderizeFilogeneticTree(): void {
    const screenSize = this.demoDiv.nativeElement.getBoundingClientRect();
    screenSize.width = screenSize.width * 0.95;
    screenSize.height = screenSize.height * 3;
    const metadata = "id,colour\nRosaceae,red\nUlmaceae,red"; //Esto serian diferentes opciones de personalización de nodos en formato csv
    this.tree = new PhylocanvasGL(
      this.demoDiv.nativeElement,
      {
        interactive: false,
        showLabels: true,
        showLeafLabels: true,
        size: screenSize,
        alignLabels: true,
        nodeSize: 16,
        source: "(((((((Rosaceae,(Elaeagnaceae,(Rhamnaceae,Ulmaceae,(Cannabaceae,(Urticaceae,Moraceae))))),(((Begoniaceae,Datiscaceae),Cucurbitaceae),(Fagaceae,((Betulaceae,Casuarinaceae),Juglandaceae,Myricaceae)))),(Fabaceae,Quillajaceae)),(Celastraceae,((Elaeocarpaceae,Cephalotaceae,(Oxalidaceae,Connaraceae)),(((Tumeraceae,Passifloraceae),Violaceae),((Calophyliaceae,Myricaceae),Clusiaceae),(Rhizophoraceae,Erythroxylaceae),Salicaceae,Chrysobalanaceae,Malphighiaceae,Euphorbiaceae,Linaceae,Caryocaraceae,Rafflesiaceae)))),((((((Rutaceae,Meliaceae),Sapindaceae,(Anacardiaceae,Burseraceae)),(Malvaceae,Cochlospermaceae,Thymelaceae,(Dipterocarpaceae,Cistaceae))),((Resedaceae,(Cleomaceae,Brassicaceae)),((Caricaceae,Moringaceae),(Tropaeolaceae,Akaniaceae)))),Staphyleaceae),(((Myrtaceae,Melastomataceae),(Onagraceae,Lythraceae)),Geraniaceae))),Vitaceae),((Cornaceae,Nyssaceae,Hydrangeaceae),(Balsaminaceae,(Polemoniaceae,(Lecythidaceae,Theaceae,Sapotaceae,Ebenaceae,(Myrsinaceae,Primulaceae),(Ericaceae,(Actinidiaceae,Sarraceniaceae))))),(((Icacinaceae,Eucommiaceae),((Solanaceae,Convolvulaceae),Boraginaceae,(Oleaceae,(Gesneriaceae,Lentibulariaceae,Plantaginaceae,Bignoniaceae,Acanthaceae,Orobanchaceae,Pedaliaceae,Lamiaceae,Phrymaceae,Scrophulariaceae,Linderniaceae,Paulowniaceae)),(Rubiaceae,(Apocynaceae,Loganiaceae,Gentianaceae)))),(Caprifoliaceae,(Apiaceae,Araliaceae),(Aquifoliaceae,(Campanulaceae,(Argophyllaceae,(Menyanthaceae,(Goodeniaceae,Asteraceae)))))))),((((Caryophyllaceae,AmaranthaceaeChenopodiaceae),((Microteaceae,Nyctaginaceae),(Kewaceae,Cactaceae,(Limeacea,Molluginaceae)))),(Simmondsiaceae,Macarthuriaceae)),((Plumbaginaceae,Polygonaceae),Droseraceae)),(Hamamelidaceae,(Paeoniaceae,(Crassulaceae,Saxifragaceae))),(Olacaceae,Santalaceae));",
        type: TreeTypes.Rectangular,
        styles: (
          metadata
            .split("\n")
            .map((line) => line.split(","))
            .reduce(
              (styles, [id, fillColour]) => {
                styles[id] = {fillColour};
                return styles;
              },
              {}
            )
        ),
      },
    );
    this.tree.setProps({
      interactive: true
    });
  }

  public onGoToFamily(): void {
    const param = this.tree['props']['selectedIds']
    if (param !== undefined) {
      this.router.navigate(['family/' + param]);
    }
  }
}
