import {Injectable} from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {environment} from "../../environments/environment";
import {MultipleFamilyAnalysis} from "../models/MultipleFamilyAnalysis";
import {BehaviorSubject, filter, map, Observable} from "rxjs";

@Injectable({
  providedIn: 'root'
})
export class DataService {
  private readonly multipleFamilyAnalysis: BehaviorSubject<MultipleFamilyAnalysis | undefined>;
  private readonly newick: BehaviorSubject<string | undefined>;

  constructor(private readonly http: HttpClient) {
    this.multipleFamilyAnalysis = new BehaviorSubject<MultipleFamilyAnalysis | undefined>(undefined);
    this.newick = new BehaviorSubject<string | undefined>(undefined);
  }

  public getMultipleFamilyAnalysis(): Observable<MultipleFamilyAnalysis> {
    return <Observable<MultipleFamilyAnalysis>>this.multipleFamilyAnalysis
      .asObservable()
      .pipe(filter(value => value !== undefined));
  }

  public listFamilyNames(): Observable<string[]> {
    if (this.multipleFamilyAnalysis === undefined) {
      throw new Error("multipleFamilyAnalysis is not initialized");
    }

    return this.getMultipleFamilyAnalysis()
      .pipe(map(mfa => Object.keys(mfa.all_results)));
  }

  public getNewick(): Observable<string> {
    return <Observable<string>>this.newick.asObservable()
      .pipe(filter(value => value !== undefined));
  }

  public loadNewick(): void {
    if (this.newick.value !== undefined) {
      throw new Error("newick is already initialized");
    }

    this.http.get<{ newick: string }>(`${environment.apiUrl}/families`)
      .pipe(map(result => result.newick))
      .subscribe(newick => this.newick.next(newick));
  }

  public loadAnalysisResults(): void {
    if (this.multipleFamilyAnalysis.value !== undefined) {
      throw new Error("multipleFamilyAnalysis is already initialized");
    }

    this.http.get<MultipleFamilyAnalysis>(`${environment.apiUrl}/results`)
      .subscribe(mfa => this.multipleFamilyAnalysis.next(mfa));
  }
}
